diff --git a/experiments/daic/testing/mnist.sh b/experiments/daic/testing/mnist.sh
new file mode 100644
index 0000000000000000000000000000000000000000..352cc8068e168231e3f50ca0ef434376cb25b43b
--- /dev/null
+++ b/experiments/daic/testing/mnist.sh
@@ -0,0 +1,17 @@
+#!/bin/bash
+
+#SBATCH --job-name="MNIST test (ECCCo)"
+#SBATCH --time=00:30:00
+#SBATCH --ntasks=10
+#SBATCH --cpus-per-task=4
+#SBATCH --partition=general
+#SBATCH --mem-per-cpu=8GB
+#SBATCH --mail-type=END     # Set mail type to 'END' to receive a mail when the job finishes. 
+
+module use /opt/insy/modulefiles          # Use DAIC INSY software collection
+module load openmpi
+
+source experiments/slurm_header.sh
+
+srun julia --project=experiments --threads $SLURM_CPUS_PER_TASK experiments/run_experiments.jl -- data=mnist output_path=results_testing mpi grid_search n_individuals=10 threaded n_each=32 > experiments/logs/grid_search_mnist.log
+ 
\ No newline at end of file
diff --git a/experiments/fmnist.jl b/experiments/fmnist.jl
index c7d6a191d2bb6e9d32221952a86b56967e580beb..7802e19d6a4cda064d45340692708e807b8bf0bc 100644
--- a/experiments/fmnist.jl
+++ b/experiments/fmnist.jl
@@ -30,7 +30,7 @@ model_tuning_params = DEFAULT_MODEL_TUNING_LARGE
 
 # Tuning parameters:
 tuning_params = DEFAULT_GENERATOR_TUNING
-tuning_params = (; tuning_params..., Λ = [tuning_params.Λ[2:end]..., [0.1, 0.1, 3.0]])
+tuning_params = (; tuning_params..., Λ = [tuning_params.Λ[2:end]..., [0.01, 0.1, 3.0]])
 
 # Additional models:
 add_models = Dict("LeNet-5" => lenet5)
diff --git a/experiments/jobscripts/tuning/generators/fmnist.sh b/experiments/jobscripts/tuning/generators/fmnist.sh
index d8aefd4009829093295769ed999f8b6a82aae9bf..45322183708ebfffb23a85fbdd3b520db0729d40 100644
--- a/experiments/jobscripts/tuning/generators/fmnist.sh
+++ b/experiments/jobscripts/tuning/generators/fmnist.sh
@@ -1,9 +1,9 @@
 #!/bin/bash
 
-#SBATCH --job-name="Grid-search Fashion MNIST (ECCCo)"
-#SBATCH --time=32:00:00
-#SBATCH --ntasks=1000
-#SBATCH --cpus-per-task=1
+#SBATCH --job-name="Fashion MNIST - Grid (ECCCo)"
+#SBATCH --time=02:00:00
+#SBATCH --ntasks=40
+#SBATCH --cpus-per-task=10
 #SBATCH --partition=compute
 #SBATCH --mem-per-cpu=8GB
 #SBATCH --account=research-eemcs-insy
@@ -11,4 +11,6 @@
 
 module load 2023r1 openmpi
 
-srun julia --project=experiments experiments/run_experiments.jl -- data=fmnist output_path=results mpi grid_search > experiments/grid_search_fmnist.log
\ No newline at end of file
+source experiments/slurm_header.sh
+
+srun julia --project=experiments --threads $SLURM_CPUS_PER_TASK experiments/run_experiments.jl -- data=fmnist output_path=results mpi grid_search threaded n_individuals=25 n_each=32 > experiments/logs/grid_search_fmnist.log
\ No newline at end of file
diff --git a/experiments/jobscripts/tuning/generators/mnist.sh b/experiments/jobscripts/tuning/generators/mnist.sh
index de7d29a66e23de3cdc808cd2ec5006a5f2e0c315..bb94324b1e36cb364c647aecdd3a2e9c167586e5 100644
--- a/experiments/jobscripts/tuning/generators/mnist.sh
+++ b/experiments/jobscripts/tuning/generators/mnist.sh
@@ -13,4 +13,4 @@ module load 2023r1 openmpi
 
 source experiments/slurm_header.sh
 
-srun julia --project=experiments --threads $SLURM_CPUS_PER_TASK experiments/run_experiments.jl -- data=mnist output_path=results mpi grid_search threaded n_individuals=1 n_each=10 > experiments/logs/grid_search_mnist.log
\ No newline at end of file
+srun julia --project=experiments --threads $SLURM_CPUS_PER_TASK experiments/run_experiments.jl -- data=mnist output_path=results mpi grid_search threaded n_individuals=25 n_each=32 > experiments/logs/grid_search_mnist.log
\ No newline at end of file
diff --git a/experiments/mnist.jl b/experiments/mnist.jl
index e4fe2251420eaa7adf0f76645c22c27d97824f9e..782811cc5be4e5603fb0deb585bb55fc7d3d2bc8 100644
--- a/experiments/mnist.jl
+++ b/experiments/mnist.jl
@@ -30,7 +30,7 @@ model_tuning_params = DEFAULT_MODEL_TUNING_LARGE
 
 # Tuning parameters:
 tuning_params = DEFAULT_GENERATOR_TUNING
-tuning_params = (; tuning_params..., Λ = [tuning_params.Λ[2:end]..., [0.1, 0.1, 3.0]])
+tuning_params = (; tuning_params..., Λ = [tuning_params.Λ[2:end]..., [0.01, 0.1, 3.0]])
 
 # Additional models:
 add_models = Dict("LeNet-5" => lenet5)
diff --git a/experiments/run_experiments.jl b/experiments/run_experiments.jl
index 8e636fd8b9740292ee6b13b5d95e6bcd600932bf..b0183cb0745a8b6a634f5538365ab6647d123599 100644
--- a/experiments/run_experiments.jl
+++ b/experiments/run_experiments.jl
@@ -52,12 +52,6 @@ if "german_credit" in datanames
     include("german_credit.jl")
 end
 
-# Credit Default
-if "credit_default" in datanames
-    @info "Running Credit Default experiment."
-    include("credit_default.jl")
-end
-
 # California Housing
 if "california_housing" in datanames
     @info "Running California Housing experiment."
diff --git a/experiments/daic/generators/fmnist.sh b/experiments/daic/generators/fmnist.sh
index 6131eb3735deea111394700327c4daa72138ccdf..83ed1794ef7c32b76df05c17df7a0fb8cb81a52c 100644
--- a/experiments/daic/generators/fmnist.sh
+++ b/experiments/daic/generators/fmnist.sh
@@ -1,9 +1,9 @@
 #!/bin/bash
 
 #SBATCH --job-name="Fashion-MNIST (ECCCo)"
 #SBATCH --time=10:00:00
 #SBATCH --ntasks=1000
 #SBATCH --cpus-per-task=1
 #SBATCH --partition=general
 #SBATCH --mem-per-cpu=8GB
 #SBATCH --mail-type=END     # Set mail type to 'END' to receive a mail when the job finishes. 
@@ -11,4 +11,6 @@
 module use /opt/insy/modulefiles          # Use DAIC INSY software collection
 module load openmpi
 
-srun julia --project=experiments experiments/run_experiments.jl -- data=fmnist retrain output_path=results threaded mpi > experiments/fmnist.log
+source experiments/slurm_header.sh
+
+srun julia --project=experiments --threads $SLURM_CPUS_PER_TASK experiments/run_experiments.jl -- data=fmnist output_path=results mpi grid_search threaded n_individuals=25 n_each=32 > experiments/logs/grid_search_fmnist.log
\ No newline at end of file
@@ -1,9 +1,9 @@
 #!/bin/bash
 
-#SBATCH --job-name="Fashion-MNIST (ECCCo)"
-#SBATCH --time=10:00:00
-#SBATCH --ntasks=1000
-#SBATCH --cpus-per-task=1
+#SBATCH --job-name="Fashion MNIST - Grid (ECCCo)"
+#SBATCH --time=02:00:00
+#SBATCH --ntasks=40
+#SBATCH --cpus-per-task=10
 #SBATCH --partition=general
 #SBATCH --mem-per-cpu=8GB
diff --git a/experiments/daic/generators/mnist.sh b/experiments/daic/generators/mnist.sh
index 4b638dd3198bb5d60501cb55a45539387cc00e55..4fcc9839fedb79abd898f6fb0c4218e2c271d992 100644
--- a/experiments/daic/generators/mnist.sh
+++ b/experiments/daic/generators/mnist.sh
@@ -1,9 +1,9 @@
 #!/bin/bash
 
 #SBATCH --job-name="MNIST (ECCCo)"
 #SBATCH --time=10:00:00
 #SBATCH --ntasks=1000
 #SBATCH --cpus-per-task=1
 #SBATCH --partition=general
 #SBATCH --mem-per-cpu=8GB
 #SBATCH --mail-type=END     # Set mail type to 'END' to receive a mail when the job finishes. 
@@ -11,4 +11,6 @@
 module use /opt/insy/modulefiles          # Use DAIC INSY software collection
 module load openmpi
 
-srun julia --project=experiments experiments/run_experiments.jl -- data=mnist output_path=results mpi > experiments/mnist.log
+source experiments/slurm_header.sh
+
+srun julia --project=experiments --threads $SLURM_CPUS_PER_TASK experiments/run_experiments.jl -- data=mnist output_path=results mpi grid_search threaded n_individuals=25 n_each=32 > experiments/logs/grid_search_mnist.log
\ No newline at end of file
@@ -1,9 +1,9 @@
 #!/bin/bash
 
-#SBATCH --job-name="MNIST (ECCCo)"
-#SBATCH --time=10:00:00
-#SBATCH --ntasks=1000
-#SBATCH --cpus-per-task=1
+#SBATCH --job-name="MNIST - Grid (ECCCo)"
+#SBATCH --time=02:00:00
+#SBATCH --ntasks=40
+#SBATCH --cpus-per-task=10
 #SBATCH --partition=general
 #SBATCH --mem-per-cpu=8GB